# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AwsProxyCertificates',
    'AzureProxyCertificates',
    'GcpProxyCertificates',
    'RuleEcsContainer',
    'RuleEcsDepend',
    'RuleEcsHttp',
    'RuleRdsDatabase',
    'RuleRdsDepend',
    'RuleRdsTcp',
    'RuleRdsTcpForwardRule',
    'RuleScaleGroupDepend',
    'RuleScaleGroupHttp',
    'RuleScaleGroupHttpHealth',
    'RuleScaleGroupHttpRouting',
    'RuleScaleGroupScaleGroup',
    'RuleVmDepend',
    'RuleVmFilter',
    'RuleVmFilterTag',
    'RuleVmHttp',
    'RuleVmHttpHealth',
    'RuleVmHttpRouting',
    'RuleVmTcp',
    'RuleVmTcpForwardRule',
    'RuleVmTcpRdp',
    'RuleVmTcpSsh',
    'ScheduleRepeat',
    'GetAwsProxyCertificatesResult',
    'GetAzureProxyCertificatesResult',
    'GetGcpProxyCertificatesResult',
    'GetRuleEcsContainerResult',
    'GetRuleEcsDependResult',
    'GetRuleEcsHttpResult',
    'GetRuleRdsDatabaseResult',
    'GetRuleRdsDependResult',
    'GetRuleRdsTcpResult',
    'GetRuleRdsTcpForwardRuleResult',
    'GetRuleScaleGroupDependResult',
    'GetRuleScaleGroupHttpResult',
    'GetRuleScaleGroupHttpHealthResult',
    'GetRuleScaleGroupHttpRoutingResult',
    'GetRuleScaleGroupScaleGroupResult',
    'GetRuleVmDependResult',
    'GetRuleVmFilterResult',
    'GetRuleVmFilterTagResult',
    'GetRuleVmHttpResult',
    'GetRuleVmHttpHealthResult',
    'GetRuleVmHttpRoutingResult',
    'GetRuleVmTcpResult',
    'GetRuleVmTcpForwardRuleResult',
    'GetRuleVmTcpRdpResult',
    'GetRuleVmTcpSshResult',
    'GetScheduleRepeatResult',
]

@pulumi.output_type
class AwsProxyCertificates(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "certSecretId":
            suggest = "cert_secret_id"
        elif key == "keySecretId":
            suggest = "key_secret_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AwsProxyCertificates. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AwsProxyCertificates.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AwsProxyCertificates.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cert_secret_id: _builtins.str,
                 key_secret_id: _builtins.str):
        """
        :param _builtins.str cert_secret_id: Certificate secret ID
        :param _builtins.str key_secret_id: Private key secret ID
        """
        pulumi.set(__self__, "cert_secret_id", cert_secret_id)
        pulumi.set(__self__, "key_secret_id", key_secret_id)

    @_builtins.property
    @pulumi.getter(name="certSecretId")
    def cert_secret_id(self) -> _builtins.str:
        """
        Certificate secret ID
        """
        return pulumi.get(self, "cert_secret_id")

    @_builtins.property
    @pulumi.getter(name="keySecretId")
    def key_secret_id(self) -> _builtins.str:
        """
        Private key secret ID
        """
        return pulumi.get(self, "key_secret_id")


@pulumi.output_type
class AzureProxyCertificates(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "certSecretId":
            suggest = "cert_secret_id"
        elif key == "keySecretId":
            suggest = "key_secret_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AzureProxyCertificates. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AzureProxyCertificates.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AzureProxyCertificates.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cert_secret_id: _builtins.str,
                 key_secret_id: _builtins.str):
        """
        :param _builtins.str cert_secret_id: ID of certificate secret uploaded to vault
        :param _builtins.str key_secret_id: ID of certificate key uploaded to vault
        """
        pulumi.set(__self__, "cert_secret_id", cert_secret_id)
        pulumi.set(__self__, "key_secret_id", key_secret_id)

    @_builtins.property
    @pulumi.getter(name="certSecretId")
    def cert_secret_id(self) -> _builtins.str:
        """
        ID of certificate secret uploaded to vault
        """
        return pulumi.get(self, "cert_secret_id")

    @_builtins.property
    @pulumi.getter(name="keySecretId")
    def key_secret_id(self) -> _builtins.str:
        """
        ID of certificate key uploaded to vault
        """
        return pulumi.get(self, "key_secret_id")


@pulumi.output_type
class GcpProxyCertificates(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "certSecretId":
            suggest = "cert_secret_id"
        elif key == "keySecretId":
            suggest = "key_secret_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GcpProxyCertificates. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GcpProxyCertificates.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GcpProxyCertificates.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cert_secret_id: _builtins.str,
                 key_secret_id: _builtins.str):
        """
        :param _builtins.str cert_secret_id: Certificate secret ID
        :param _builtins.str key_secret_id: Private key secret ID
        """
        pulumi.set(__self__, "cert_secret_id", cert_secret_id)
        pulumi.set(__self__, "key_secret_id", key_secret_id)

    @_builtins.property
    @pulumi.getter(name="certSecretId")
    def cert_secret_id(self) -> _builtins.str:
        """
        Certificate secret ID
        """
        return pulumi.get(self, "cert_secret_id")

    @_builtins.property
    @pulumi.getter(name="keySecretId")
    def key_secret_id(self) -> _builtins.str:
        """
        Private key secret ID
        """
        return pulumi.get(self, "key_secret_id")


@pulumi.output_type
class RuleEcsContainer(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "taskCount":
            suggest = "task_count"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleEcsContainer. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleEcsContainer.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleEcsContainer.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cluster: _builtins.str,
                 region: _builtins.str,
                 service: _builtins.str,
                 task_count: Optional[_builtins.int] = None):
        """
        :param _builtins.str cluster: Name of cluster in which service belong to
        :param _builtins.str region: Region of cluster
        :param _builtins.str service: Name of service to be onboarded
        :param _builtins.int task_count: Desired number of tasks on warming up a rule
        """
        pulumi.set(__self__, "cluster", cluster)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "service", service)
        if task_count is not None:
            pulumi.set(__self__, "task_count", task_count)

    @_builtins.property
    @pulumi.getter
    def cluster(self) -> _builtins.str:
        """
        Name of cluster in which service belong to
        """
        return pulumi.get(self, "cluster")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        Region of cluster
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def service(self) -> _builtins.str:
        """
        Name of service to be onboarded
        """
        return pulumi.get(self, "service")

    @_builtins.property
    @pulumi.getter(name="taskCount")
    def task_count(self) -> Optional[_builtins.int]:
        """
        Desired number of tasks on warming up a rule
        """
        return pulumi.get(self, "task_count")


@pulumi.output_type
class RuleEcsDepend(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ruleId":
            suggest = "rule_id"
        elif key == "delayInSec":
            suggest = "delay_in_sec"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleEcsDepend. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleEcsDepend.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleEcsDepend.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rule_id: _builtins.int,
                 delay_in_sec: Optional[_builtins.int] = None):
        """
        :param _builtins.int rule_id: Rule id of the dependent rule
        :param _builtins.int delay_in_sec: Number of seconds the rule should wait after warming up the dependent rule
        """
        pulumi.set(__self__, "rule_id", rule_id)
        if delay_in_sec is not None:
            pulumi.set(__self__, "delay_in_sec", delay_in_sec)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.int:
        """
        Rule id of the dependent rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="delayInSec")
    def delay_in_sec(self) -> Optional[_builtins.int]:
        """
        Number of seconds the rule should wait after warming up the dependent rule
        """
        return pulumi.get(self, "delay_in_sec")


@pulumi.output_type
class RuleEcsHttp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "proxyId":
            suggest = "proxy_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleEcsHttp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleEcsHttp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleEcsHttp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 proxy_id: _builtins.str):
        """
        :param _builtins.str proxy_id: Id of the proxy
        """
        pulumi.set(__self__, "proxy_id", proxy_id)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the proxy
        """
        return pulumi.get(self, "proxy_id")


@pulumi.output_type
class RuleRdsDatabase(dict):
    def __init__(__self__, *,
                 id: _builtins.str,
                 region: _builtins.str):
        """
        :param _builtins.str id: ID of the database
        :param _builtins.str region: Region to which database belong to
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the database
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        Region to which database belong to
        """
        return pulumi.get(self, "region")


@pulumi.output_type
class RuleRdsDepend(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ruleId":
            suggest = "rule_id"
        elif key == "delayInSec":
            suggest = "delay_in_sec"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleRdsDepend. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleRdsDepend.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleRdsDepend.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rule_id: _builtins.int,
                 delay_in_sec: Optional[_builtins.int] = None):
        """
        :param _builtins.int rule_id: Rule id of the dependent rule
        :param _builtins.int delay_in_sec: Number of seconds the rule should wait after warming up the dependent rule
        """
        pulumi.set(__self__, "rule_id", rule_id)
        if delay_in_sec is not None:
            pulumi.set(__self__, "delay_in_sec", delay_in_sec)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.int:
        """
        Rule id of the dependent rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="delayInSec")
    def delay_in_sec(self) -> Optional[_builtins.int]:
        """
        Number of seconds the rule should wait after warming up the dependent rule
        """
        return pulumi.get(self, "delay_in_sec")


@pulumi.output_type
class RuleRdsTcp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "proxyId":
            suggest = "proxy_id"
        elif key == "forwardRules":
            suggest = "forward_rules"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleRdsTcp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleRdsTcp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleRdsTcp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 proxy_id: _builtins.str,
                 forward_rules: Optional[Sequence['outputs.RuleRdsTcpForwardRule']] = None):
        """
        :param _builtins.str proxy_id: Id of the Proxy
        :param Sequence['RuleRdsTcpForwardRuleArgs'] forward_rules: Additional tcp forwarding rules
        """
        pulumi.set(__self__, "proxy_id", proxy_id)
        if forward_rules is not None:
            pulumi.set(__self__, "forward_rules", forward_rules)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the Proxy
        """
        return pulumi.get(self, "proxy_id")

    @_builtins.property
    @pulumi.getter(name="forwardRules")
    def forward_rules(self) -> Optional[Sequence['outputs.RuleRdsTcpForwardRule']]:
        """
        Additional tcp forwarding rules
        """
        return pulumi.get(self, "forward_rules")


@pulumi.output_type
class RuleRdsTcpForwardRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectOn":
            suggest = "connect_on"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleRdsTcpForwardRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleRdsTcpForwardRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleRdsTcpForwardRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 port: _builtins.int,
                 connect_on: Optional[_builtins.int] = None):
        """
        :param _builtins.int port: Port to listen on the vm
        :param _builtins.int connect_on: Port to listen on the proxy
        """
        pulumi.set(__self__, "port", port)
        if connect_on is not None:
            pulumi.set(__self__, "connect_on", connect_on)

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Port to listen on the vm
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="connectOn")
    def connect_on(self) -> Optional[_builtins.int]:
        """
        Port to listen on the proxy
        """
        return pulumi.get(self, "connect_on")


@pulumi.output_type
class RuleScaleGroupDepend(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ruleId":
            suggest = "rule_id"
        elif key == "delayInSec":
            suggest = "delay_in_sec"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleScaleGroupDepend. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleScaleGroupDepend.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleScaleGroupDepend.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rule_id: _builtins.int,
                 delay_in_sec: Optional[_builtins.int] = None):
        """
        :param _builtins.int rule_id: Rule id of the dependent rule
        :param _builtins.int delay_in_sec: Number of seconds the rule should wait after warming up the dependent rule
        """
        pulumi.set(__self__, "rule_id", rule_id)
        if delay_in_sec is not None:
            pulumi.set(__self__, "delay_in_sec", delay_in_sec)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.int:
        """
        Rule id of the dependent rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="delayInSec")
    def delay_in_sec(self) -> Optional[_builtins.int]:
        """
        Number of seconds the rule should wait after warming up the dependent rule
        """
        return pulumi.get(self, "delay_in_sec")


@pulumi.output_type
class RuleScaleGroupHttp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "proxyId":
            suggest = "proxy_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleScaleGroupHttp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleScaleGroupHttp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleScaleGroupHttp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 proxy_id: _builtins.str,
                 healths: Optional[Sequence['outputs.RuleScaleGroupHttpHealth']] = None,
                 routings: Optional[Sequence['outputs.RuleScaleGroupHttpRouting']] = None):
        """
        :param _builtins.str proxy_id: Id of the proxy
        :param Sequence['RuleScaleGroupHttpHealthArgs'] healths: Health Check Details
        :param Sequence['RuleScaleGroupHttpRoutingArgs'] routings: Routing configuration used to access the scaling group
        """
        pulumi.set(__self__, "proxy_id", proxy_id)
        if healths is not None:
            pulumi.set(__self__, "healths", healths)
        if routings is not None:
            pulumi.set(__self__, "routings", routings)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the proxy
        """
        return pulumi.get(self, "proxy_id")

    @_builtins.property
    @pulumi.getter
    def healths(self) -> Optional[Sequence['outputs.RuleScaleGroupHttpHealth']]:
        """
        Health Check Details
        """
        return pulumi.get(self, "healths")

    @_builtins.property
    @pulumi.getter
    def routings(self) -> Optional[Sequence['outputs.RuleScaleGroupHttpRouting']]:
        """
        Routing configuration used to access the scaling group
        """
        return pulumi.get(self, "routings")


@pulumi.output_type
class RuleScaleGroupHttpHealth(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "statusCodeFrom":
            suggest = "status_code_from"
        elif key == "statusCodeTo":
            suggest = "status_code_to"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleScaleGroupHttpHealth. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleScaleGroupHttpHealth.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleScaleGroupHttpHealth.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 port: _builtins.int,
                 protocol: _builtins.str,
                 path: Optional[_builtins.str] = None,
                 status_code_from: Optional[_builtins.int] = None,
                 status_code_to: Optional[_builtins.int] = None,
                 timeout: Optional[_builtins.int] = None):
        """
        :param _builtins.int port: Health check port on the VM
        :param _builtins.str protocol: Protocol can be http or https
        :param _builtins.str path: API path to use for health check
        :param _builtins.int status_code_from: Lower limit for acceptable status code
        :param _builtins.int status_code_to: Upper limit for acceptable status code
        :param _builtins.int timeout: Health check timeout
        """
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if status_code_from is not None:
            pulumi.set(__self__, "status_code_from", status_code_from)
        if status_code_to is not None:
            pulumi.set(__self__, "status_code_to", status_code_to)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Health check port on the VM
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> _builtins.str:
        """
        Protocol can be http or https
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[_builtins.str]:
        """
        API path to use for health check
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="statusCodeFrom")
    def status_code_from(self) -> Optional[_builtins.int]:
        """
        Lower limit for acceptable status code
        """
        return pulumi.get(self, "status_code_from")

    @_builtins.property
    @pulumi.getter(name="statusCodeTo")
    def status_code_to(self) -> Optional[_builtins.int]:
        """
        Upper limit for acceptable status code
        """
        return pulumi.get(self, "status_code_to")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[_builtins.int]:
        """
        Health check timeout
        """
        return pulumi.get(self, "timeout")


@pulumi.output_type
class RuleScaleGroupHttpRouting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sourceProtocol":
            suggest = "source_protocol"
        elif key == "targetProtocol":
            suggest = "target_protocol"
        elif key == "sourcePort":
            suggest = "source_port"
        elif key == "targetPort":
            suggest = "target_port"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleScaleGroupHttpRouting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleScaleGroupHttpRouting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleScaleGroupHttpRouting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 source_protocol: _builtins.str,
                 target_protocol: _builtins.str,
                 action: Optional[_builtins.str] = None,
                 source_port: Optional[_builtins.int] = None,
                 target_port: Optional[_builtins.int] = None):
        """
        :param _builtins.str source_protocol: Source protocol of the proxy can be http or https
        :param _builtins.str target_protocol: Target protocol of the instance can be http or https
        :param _builtins.str action: Organization Identifier for the Entity
        :param _builtins.int source_port: Port on the proxy
        :param _builtins.int target_port: Port on the VM
        """
        pulumi.set(__self__, "source_protocol", source_protocol)
        pulumi.set(__self__, "target_protocol", target_protocol)
        if action is not None:
            pulumi.set(__self__, "action", action)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if target_port is not None:
            pulumi.set(__self__, "target_port", target_port)

    @_builtins.property
    @pulumi.getter(name="sourceProtocol")
    def source_protocol(self) -> _builtins.str:
        """
        Source protocol of the proxy can be http or https
        """
        return pulumi.get(self, "source_protocol")

    @_builtins.property
    @pulumi.getter(name="targetProtocol")
    def target_protocol(self) -> _builtins.str:
        """
        Target protocol of the instance can be http or https
        """
        return pulumi.get(self, "target_protocol")

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[_builtins.str]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[_builtins.int]:
        """
        Port on the proxy
        """
        return pulumi.get(self, "source_port")

    @_builtins.property
    @pulumi.getter(name="targetPort")
    def target_port(self) -> Optional[_builtins.int]:
        """
        Port on the VM
        """
        return pulumi.get(self, "target_port")


@pulumi.output_type
class RuleScaleGroupScaleGroup(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "onDemand":
            suggest = "on_demand"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleScaleGroupScaleGroup. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleScaleGroupScaleGroup.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleScaleGroupScaleGroup.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 desired: _builtins.int,
                 id: _builtins.str,
                 max: _builtins.int,
                 min: _builtins.int,
                 name: _builtins.str,
                 on_demand: _builtins.int,
                 region: Optional[_builtins.str] = None,
                 zone: Optional[_builtins.str] = None):
        """
        :param _builtins.int desired: Desired capacity of the Scaling Group
        :param _builtins.str id: ID of the Scaling Group
        :param _builtins.int max: Maximum capacity of the Scaling Group
        :param _builtins.int min: Minimum capacity of the Scaling Group
        :param _builtins.str name: Name of the Scaling Group
        :param _builtins.int on_demand: On-demand capacity of the Scaling Group
        :param _builtins.str region: Region of the Scaling Group
        :param _builtins.str zone: Zone of the Scaling Group. Needed for GCP only
        """
        pulumi.set(__self__, "desired", desired)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "max", max)
        pulumi.set(__self__, "min", min)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "on_demand", on_demand)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def desired(self) -> _builtins.int:
        """
        Desired capacity of the Scaling Group
        """
        return pulumi.get(self, "desired")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the Scaling Group
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def max(self) -> _builtins.int:
        """
        Maximum capacity of the Scaling Group
        """
        return pulumi.get(self, "max")

    @_builtins.property
    @pulumi.getter
    def min(self) -> _builtins.int:
        """
        Minimum capacity of the Scaling Group
        """
        return pulumi.get(self, "min")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the Scaling Group
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="onDemand")
    def on_demand(self) -> _builtins.int:
        """
        On-demand capacity of the Scaling Group
        """
        return pulumi.get(self, "on_demand")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        """
        Region of the Scaling Group
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[_builtins.str]:
        """
        Zone of the Scaling Group. Needed for GCP only
        """
        return pulumi.get(self, "zone")


@pulumi.output_type
class RuleVmDepend(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ruleId":
            suggest = "rule_id"
        elif key == "delayInSec":
            suggest = "delay_in_sec"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmDepend. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmDepend.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmDepend.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rule_id: _builtins.int,
                 delay_in_sec: Optional[_builtins.int] = None):
        """
        :param _builtins.int rule_id: Rule id of the dependent rule
        :param _builtins.int delay_in_sec: Number of seconds the rule should wait after warming up the dependent rule
        """
        pulumi.set(__self__, "rule_id", rule_id)
        if delay_in_sec is not None:
            pulumi.set(__self__, "delay_in_sec", delay_in_sec)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.int:
        """
        Rule id of the dependent rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="delayInSec")
    def delay_in_sec(self) -> Optional[_builtins.int]:
        """
        Number of seconds the rule should wait after warming up the dependent rule
        """
        return pulumi.get(self, "delay_in_sec")


@pulumi.output_type
class RuleVmFilter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "vmIds":
            suggest = "vm_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmFilter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmFilter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmFilter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 vm_ids: Sequence[_builtins.str],
                 regions: Optional[Sequence[_builtins.str]] = None,
                 tags: Optional[Sequence['outputs.RuleVmFilterTag']] = None,
                 zones: Optional[Sequence[_builtins.str]] = None):
        """
        :param Sequence[_builtins.str] vm_ids: Ids of instances that needs to be managed using the AutoStopping rules
        :param Sequence[_builtins.str] regions: Regions of instances that needs to be managed using the AutoStopping rules
        :param Sequence['RuleVmFilterTagArgs'] tags: Tags of instances that needs to be managed using the AutoStopping rules
        :param Sequence[_builtins.str] zones: Zones of instances that needs to be managed using the AutoStopping rules
        """
        pulumi.set(__self__, "vm_ids", vm_ids)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zones is not None:
            pulumi.set(__self__, "zones", zones)

    @_builtins.property
    @pulumi.getter(name="vmIds")
    def vm_ids(self) -> Sequence[_builtins.str]:
        """
        Ids of instances that needs to be managed using the AutoStopping rules
        """
        return pulumi.get(self, "vm_ids")

    @_builtins.property
    @pulumi.getter
    def regions(self) -> Optional[Sequence[_builtins.str]]:
        """
        Regions of instances that needs to be managed using the AutoStopping rules
        """
        return pulumi.get(self, "regions")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence['outputs.RuleVmFilterTag']]:
        """
        Tags of instances that needs to be managed using the AutoStopping rules
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def zones(self) -> Optional[Sequence[_builtins.str]]:
        """
        Zones of instances that needs to be managed using the AutoStopping rules
        """
        return pulumi.get(self, "zones")


@pulumi.output_type
class RuleVmFilterTag(dict):
    def __init__(__self__, *,
                 key: _builtins.str,
                 value: _builtins.str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> _builtins.str:
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        return pulumi.get(self, "value")


@pulumi.output_type
class RuleVmHttp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "proxyId":
            suggest = "proxy_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmHttp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmHttp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmHttp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 proxy_id: _builtins.str,
                 healths: Optional[Sequence['outputs.RuleVmHttpHealth']] = None,
                 routings: Optional[Sequence['outputs.RuleVmHttpRouting']] = None):
        """
        :param _builtins.str proxy_id: Id of the proxy
        :param Sequence['RuleVmHttpHealthArgs'] healths: Health Check Details
        :param Sequence['RuleVmHttpRoutingArgs'] routings: Routing configuration used to access the instances
        """
        pulumi.set(__self__, "proxy_id", proxy_id)
        if healths is not None:
            pulumi.set(__self__, "healths", healths)
        if routings is not None:
            pulumi.set(__self__, "routings", routings)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the proxy
        """
        return pulumi.get(self, "proxy_id")

    @_builtins.property
    @pulumi.getter
    def healths(self) -> Optional[Sequence['outputs.RuleVmHttpHealth']]:
        """
        Health Check Details
        """
        return pulumi.get(self, "healths")

    @_builtins.property
    @pulumi.getter
    def routings(self) -> Optional[Sequence['outputs.RuleVmHttpRouting']]:
        """
        Routing configuration used to access the instances
        """
        return pulumi.get(self, "routings")


@pulumi.output_type
class RuleVmHttpHealth(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "statusCodeFrom":
            suggest = "status_code_from"
        elif key == "statusCodeTo":
            suggest = "status_code_to"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmHttpHealth. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmHttpHealth.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmHttpHealth.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 port: _builtins.int,
                 protocol: _builtins.str,
                 path: Optional[_builtins.str] = None,
                 status_code_from: Optional[_builtins.int] = None,
                 status_code_to: Optional[_builtins.int] = None,
                 timeout: Optional[_builtins.int] = None):
        """
        :param _builtins.int port: Health check port on the VM
        :param _builtins.str protocol: Protocol can be http or https
        :param _builtins.str path: API path to use for health check
        :param _builtins.int status_code_from: Lower limit for acceptable status code
        :param _builtins.int status_code_to: Upper limit for acceptable status code
        :param _builtins.int timeout: Health check timeout
        """
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if status_code_from is not None:
            pulumi.set(__self__, "status_code_from", status_code_from)
        if status_code_to is not None:
            pulumi.set(__self__, "status_code_to", status_code_to)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Health check port on the VM
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> _builtins.str:
        """
        Protocol can be http or https
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[_builtins.str]:
        """
        API path to use for health check
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="statusCodeFrom")
    def status_code_from(self) -> Optional[_builtins.int]:
        """
        Lower limit for acceptable status code
        """
        return pulumi.get(self, "status_code_from")

    @_builtins.property
    @pulumi.getter(name="statusCodeTo")
    def status_code_to(self) -> Optional[_builtins.int]:
        """
        Upper limit for acceptable status code
        """
        return pulumi.get(self, "status_code_to")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[_builtins.int]:
        """
        Health check timeout
        """
        return pulumi.get(self, "timeout")


@pulumi.output_type
class RuleVmHttpRouting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sourceProtocol":
            suggest = "source_protocol"
        elif key == "targetProtocol":
            suggest = "target_protocol"
        elif key == "sourcePort":
            suggest = "source_port"
        elif key == "targetPort":
            suggest = "target_port"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmHttpRouting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmHttpRouting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmHttpRouting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 source_protocol: _builtins.str,
                 target_protocol: _builtins.str,
                 action: Optional[_builtins.str] = None,
                 source_port: Optional[_builtins.int] = None,
                 target_port: Optional[_builtins.int] = None):
        """
        :param _builtins.str source_protocol: Source protocol of the proxy can be http or https
        :param _builtins.str target_protocol: Target protocol of the instance can be http or https
        :param _builtins.str action: Organization Identifier for the Entity
        :param _builtins.int source_port: Port on the proxy
        :param _builtins.int target_port: Port on the VM
        """
        pulumi.set(__self__, "source_protocol", source_protocol)
        pulumi.set(__self__, "target_protocol", target_protocol)
        if action is not None:
            pulumi.set(__self__, "action", action)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if target_port is not None:
            pulumi.set(__self__, "target_port", target_port)

    @_builtins.property
    @pulumi.getter(name="sourceProtocol")
    def source_protocol(self) -> _builtins.str:
        """
        Source protocol of the proxy can be http or https
        """
        return pulumi.get(self, "source_protocol")

    @_builtins.property
    @pulumi.getter(name="targetProtocol")
    def target_protocol(self) -> _builtins.str:
        """
        Target protocol of the instance can be http or https
        """
        return pulumi.get(self, "target_protocol")

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[_builtins.str]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[_builtins.int]:
        """
        Port on the proxy
        """
        return pulumi.get(self, "source_port")

    @_builtins.property
    @pulumi.getter(name="targetPort")
    def target_port(self) -> Optional[_builtins.int]:
        """
        Port on the VM
        """
        return pulumi.get(self, "target_port")


@pulumi.output_type
class RuleVmTcp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "proxyId":
            suggest = "proxy_id"
        elif key == "forwardRules":
            suggest = "forward_rules"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmTcp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmTcp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmTcp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 proxy_id: _builtins.str,
                 forward_rules: Optional[Sequence['outputs.RuleVmTcpForwardRule']] = None,
                 rdps: Optional[Sequence['outputs.RuleVmTcpRdp']] = None,
                 sshes: Optional[Sequence['outputs.RuleVmTcpSsh']] = None):
        """
        :param _builtins.str proxy_id: Id of the Proxy
        :param Sequence['RuleVmTcpForwardRuleArgs'] forward_rules: Additional tcp forwarding rules
        :param Sequence['RuleVmTcpRdpArgs'] rdps: RDP configuration
        :param Sequence['RuleVmTcpSshArgs'] sshes: SSH configuration
        """
        pulumi.set(__self__, "proxy_id", proxy_id)
        if forward_rules is not None:
            pulumi.set(__self__, "forward_rules", forward_rules)
        if rdps is not None:
            pulumi.set(__self__, "rdps", rdps)
        if sshes is not None:
            pulumi.set(__self__, "sshes", sshes)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the Proxy
        """
        return pulumi.get(self, "proxy_id")

    @_builtins.property
    @pulumi.getter(name="forwardRules")
    def forward_rules(self) -> Optional[Sequence['outputs.RuleVmTcpForwardRule']]:
        """
        Additional tcp forwarding rules
        """
        return pulumi.get(self, "forward_rules")

    @_builtins.property
    @pulumi.getter
    def rdps(self) -> Optional[Sequence['outputs.RuleVmTcpRdp']]:
        """
        RDP configuration
        """
        return pulumi.get(self, "rdps")

    @_builtins.property
    @pulumi.getter
    def sshes(self) -> Optional[Sequence['outputs.RuleVmTcpSsh']]:
        """
        SSH configuration
        """
        return pulumi.get(self, "sshes")


@pulumi.output_type
class RuleVmTcpForwardRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectOn":
            suggest = "connect_on"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmTcpForwardRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmTcpForwardRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmTcpForwardRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 port: _builtins.int,
                 connect_on: Optional[_builtins.int] = None):
        """
        :param _builtins.int port: Port to listen on the vm
        :param _builtins.int connect_on: Port to listen on the proxy
        """
        pulumi.set(__self__, "port", port)
        if connect_on is not None:
            pulumi.set(__self__, "connect_on", connect_on)

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Port to listen on the vm
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="connectOn")
    def connect_on(self) -> Optional[_builtins.int]:
        """
        Port to listen on the proxy
        """
        return pulumi.get(self, "connect_on")


@pulumi.output_type
class RuleVmTcpRdp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectOn":
            suggest = "connect_on"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmTcpRdp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmTcpRdp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmTcpRdp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connect_on: Optional[_builtins.int] = None,
                 port: Optional[_builtins.int] = None):
        """
        :param _builtins.int connect_on: Port to listen on the proxy
        :param _builtins.int port: Port to listen on the vm
        """
        if connect_on is not None:
            pulumi.set(__self__, "connect_on", connect_on)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="connectOn")
    def connect_on(self) -> Optional[_builtins.int]:
        """
        Port to listen on the proxy
        """
        return pulumi.get(self, "connect_on")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        Port to listen on the vm
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class RuleVmTcpSsh(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectOn":
            suggest = "connect_on"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleVmTcpSsh. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleVmTcpSsh.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleVmTcpSsh.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connect_on: Optional[_builtins.int] = None,
                 port: Optional[_builtins.int] = None):
        """
        :param _builtins.int connect_on: Port to listen on the proxy
        :param _builtins.int port: Port to listen on the vm
        """
        if connect_on is not None:
            pulumi.set(__self__, "connect_on", connect_on)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="connectOn")
    def connect_on(self) -> Optional[_builtins.int]:
        """
        Port to listen on the proxy
        """
        return pulumi.get(self, "connect_on")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        Port to listen on the vm
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class ScheduleRepeat(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "endTime":
            suggest = "end_time"
        elif key == "startTime":
            suggest = "start_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ScheduleRepeat. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ScheduleRepeat.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ScheduleRepeat.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 days: Sequence[_builtins.str],
                 end_time: Optional[_builtins.str] = None,
                 start_time: Optional[_builtins.str] = None):
        """
        :param Sequence[_builtins.str] days: List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        :param _builtins.str end_time: Ending time of schedule action on the day. Defaults to 24:00Hrs unless specified. Accepted format is HH:MM. Eg : 20:00 for 8pm
        :param _builtins.str start_time: Starting time of schedule action on the day. Defaults to 00:00Hrs unless specified. Accepted format is HH:MM. Eg : 13:15 for 01:15pm
        """
        pulumi.set(__self__, "days", days)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)

    @_builtins.property
    @pulumi.getter
    def days(self) -> Sequence[_builtins.str]:
        """
        List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        """
        return pulumi.get(self, "days")

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[_builtins.str]:
        """
        Ending time of schedule action on the day. Defaults to 24:00Hrs unless specified. Accepted format is HH:MM. Eg : 20:00 for 8pm
        """
        return pulumi.get(self, "end_time")

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[_builtins.str]:
        """
        Starting time of schedule action on the day. Defaults to 00:00Hrs unless specified. Accepted format is HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "start_time")


@pulumi.output_type
class GetAwsProxyCertificatesResult(dict):
    def __init__(__self__, *,
                 cert_secret_id: _builtins.str,
                 key_secret_id: _builtins.str):
        """
        :param _builtins.str cert_secret_id: Certificate secret ID
        :param _builtins.str key_secret_id: Private key secret ID
        """
        pulumi.set(__self__, "cert_secret_id", cert_secret_id)
        pulumi.set(__self__, "key_secret_id", key_secret_id)

    @_builtins.property
    @pulumi.getter(name="certSecretId")
    def cert_secret_id(self) -> _builtins.str:
        """
        Certificate secret ID
        """
        return pulumi.get(self, "cert_secret_id")

    @_builtins.property
    @pulumi.getter(name="keySecretId")
    def key_secret_id(self) -> _builtins.str:
        """
        Private key secret ID
        """
        return pulumi.get(self, "key_secret_id")


@pulumi.output_type
class GetAzureProxyCertificatesResult(dict):
    def __init__(__self__, *,
                 cert_secret_id: _builtins.str,
                 key_secret_id: _builtins.str):
        """
        :param _builtins.str cert_secret_id: ID of certificate secret uploaded to vault
        :param _builtins.str key_secret_id: ID of certificate key uploaded to vault
        """
        pulumi.set(__self__, "cert_secret_id", cert_secret_id)
        pulumi.set(__self__, "key_secret_id", key_secret_id)

    @_builtins.property
    @pulumi.getter(name="certSecretId")
    def cert_secret_id(self) -> _builtins.str:
        """
        ID of certificate secret uploaded to vault
        """
        return pulumi.get(self, "cert_secret_id")

    @_builtins.property
    @pulumi.getter(name="keySecretId")
    def key_secret_id(self) -> _builtins.str:
        """
        ID of certificate key uploaded to vault
        """
        return pulumi.get(self, "key_secret_id")


@pulumi.output_type
class GetGcpProxyCertificatesResult(dict):
    def __init__(__self__, *,
                 cert_secret_id: _builtins.str,
                 key_secret_id: _builtins.str):
        """
        :param _builtins.str cert_secret_id: Certificate secret ID
        :param _builtins.str key_secret_id: Private key secret ID
        """
        pulumi.set(__self__, "cert_secret_id", cert_secret_id)
        pulumi.set(__self__, "key_secret_id", key_secret_id)

    @_builtins.property
    @pulumi.getter(name="certSecretId")
    def cert_secret_id(self) -> _builtins.str:
        """
        Certificate secret ID
        """
        return pulumi.get(self, "cert_secret_id")

    @_builtins.property
    @pulumi.getter(name="keySecretId")
    def key_secret_id(self) -> _builtins.str:
        """
        Private key secret ID
        """
        return pulumi.get(self, "key_secret_id")


@pulumi.output_type
class GetRuleEcsContainerResult(dict):
    def __init__(__self__, *,
                 cluster: _builtins.str,
                 region: _builtins.str,
                 service: _builtins.str,
                 task_count: Optional[_builtins.int] = None):
        """
        :param _builtins.str cluster: Name of cluster in which service belong to
        :param _builtins.str region: Region of cluster
        :param _builtins.str service: Name of service to be onboarded
        :param _builtins.int task_count: Desired number of tasks on warming up a rule
        """
        pulumi.set(__self__, "cluster", cluster)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "service", service)
        if task_count is not None:
            pulumi.set(__self__, "task_count", task_count)

    @_builtins.property
    @pulumi.getter
    def cluster(self) -> _builtins.str:
        """
        Name of cluster in which service belong to
        """
        return pulumi.get(self, "cluster")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        Region of cluster
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def service(self) -> _builtins.str:
        """
        Name of service to be onboarded
        """
        return pulumi.get(self, "service")

    @_builtins.property
    @pulumi.getter(name="taskCount")
    def task_count(self) -> Optional[_builtins.int]:
        """
        Desired number of tasks on warming up a rule
        """
        return pulumi.get(self, "task_count")


@pulumi.output_type
class GetRuleEcsDependResult(dict):
    def __init__(__self__, *,
                 rule_id: _builtins.int,
                 delay_in_sec: Optional[_builtins.int] = None):
        """
        :param _builtins.int rule_id: Rule id of the dependent rule
        :param _builtins.int delay_in_sec: Number of seconds the rule should wait after warming up the dependent rule
        """
        pulumi.set(__self__, "rule_id", rule_id)
        if delay_in_sec is not None:
            pulumi.set(__self__, "delay_in_sec", delay_in_sec)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.int:
        """
        Rule id of the dependent rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="delayInSec")
    def delay_in_sec(self) -> Optional[_builtins.int]:
        """
        Number of seconds the rule should wait after warming up the dependent rule
        """
        return pulumi.get(self, "delay_in_sec")


@pulumi.output_type
class GetRuleEcsHttpResult(dict):
    def __init__(__self__, *,
                 proxy_id: _builtins.str):
        """
        :param _builtins.str proxy_id: Id of the proxy
        """
        pulumi.set(__self__, "proxy_id", proxy_id)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the proxy
        """
        return pulumi.get(self, "proxy_id")


@pulumi.output_type
class GetRuleRdsDatabaseResult(dict):
    def __init__(__self__, *,
                 id: _builtins.str,
                 region: _builtins.str):
        """
        :param _builtins.str id: ID of the database
        :param _builtins.str region: Region to which database belong to
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the database
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        Region to which database belong to
        """
        return pulumi.get(self, "region")


@pulumi.output_type
class GetRuleRdsDependResult(dict):
    def __init__(__self__, *,
                 rule_id: _builtins.int,
                 delay_in_sec: Optional[_builtins.int] = None):
        """
        :param _builtins.int rule_id: Rule id of the dependent rule
        :param _builtins.int delay_in_sec: Number of seconds the rule should wait after warming up the dependent rule
        """
        pulumi.set(__self__, "rule_id", rule_id)
        if delay_in_sec is not None:
            pulumi.set(__self__, "delay_in_sec", delay_in_sec)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.int:
        """
        Rule id of the dependent rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="delayInSec")
    def delay_in_sec(self) -> Optional[_builtins.int]:
        """
        Number of seconds the rule should wait after warming up the dependent rule
        """
        return pulumi.get(self, "delay_in_sec")


@pulumi.output_type
class GetRuleRdsTcpResult(dict):
    def __init__(__self__, *,
                 proxy_id: _builtins.str,
                 forward_rules: Optional[Sequence['outputs.GetRuleRdsTcpForwardRuleResult']] = None):
        """
        :param _builtins.str proxy_id: Id of the Proxy
        :param Sequence['GetRuleRdsTcpForwardRuleArgs'] forward_rules: Additional tcp forwarding rules
        """
        pulumi.set(__self__, "proxy_id", proxy_id)
        if forward_rules is not None:
            pulumi.set(__self__, "forward_rules", forward_rules)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the Proxy
        """
        return pulumi.get(self, "proxy_id")

    @_builtins.property
    @pulumi.getter(name="forwardRules")
    def forward_rules(self) -> Optional[Sequence['outputs.GetRuleRdsTcpForwardRuleResult']]:
        """
        Additional tcp forwarding rules
        """
        return pulumi.get(self, "forward_rules")


@pulumi.output_type
class GetRuleRdsTcpForwardRuleResult(dict):
    def __init__(__self__, *,
                 port: _builtins.int,
                 connect_on: Optional[_builtins.int] = None):
        """
        :param _builtins.int port: Port to listen on the vm
        :param _builtins.int connect_on: Port to listen on the proxy
        """
        pulumi.set(__self__, "port", port)
        if connect_on is not None:
            pulumi.set(__self__, "connect_on", connect_on)

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Port to listen on the vm
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="connectOn")
    def connect_on(self) -> Optional[_builtins.int]:
        """
        Port to listen on the proxy
        """
        return pulumi.get(self, "connect_on")


@pulumi.output_type
class GetRuleScaleGroupDependResult(dict):
    def __init__(__self__, *,
                 rule_id: _builtins.int,
                 delay_in_sec: Optional[_builtins.int] = None):
        """
        :param _builtins.int rule_id: Rule id of the dependent rule
        :param _builtins.int delay_in_sec: Number of seconds the rule should wait after warming up the dependent rule
        """
        pulumi.set(__self__, "rule_id", rule_id)
        if delay_in_sec is not None:
            pulumi.set(__self__, "delay_in_sec", delay_in_sec)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.int:
        """
        Rule id of the dependent rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="delayInSec")
    def delay_in_sec(self) -> Optional[_builtins.int]:
        """
        Number of seconds the rule should wait after warming up the dependent rule
        """
        return pulumi.get(self, "delay_in_sec")


@pulumi.output_type
class GetRuleScaleGroupHttpResult(dict):
    def __init__(__self__, *,
                 proxy_id: _builtins.str,
                 healths: Optional[Sequence['outputs.GetRuleScaleGroupHttpHealthResult']] = None,
                 routings: Optional[Sequence['outputs.GetRuleScaleGroupHttpRoutingResult']] = None):
        """
        :param _builtins.str proxy_id: Id of the proxy
        :param Sequence['GetRuleScaleGroupHttpHealthArgs'] healths: Health Check Details
        :param Sequence['GetRuleScaleGroupHttpRoutingArgs'] routings: Routing configuration used to access the scaling group
        """
        pulumi.set(__self__, "proxy_id", proxy_id)
        if healths is not None:
            pulumi.set(__self__, "healths", healths)
        if routings is not None:
            pulumi.set(__self__, "routings", routings)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the proxy
        """
        return pulumi.get(self, "proxy_id")

    @_builtins.property
    @pulumi.getter
    def healths(self) -> Optional[Sequence['outputs.GetRuleScaleGroupHttpHealthResult']]:
        """
        Health Check Details
        """
        return pulumi.get(self, "healths")

    @_builtins.property
    @pulumi.getter
    def routings(self) -> Optional[Sequence['outputs.GetRuleScaleGroupHttpRoutingResult']]:
        """
        Routing configuration used to access the scaling group
        """
        return pulumi.get(self, "routings")


@pulumi.output_type
class GetRuleScaleGroupHttpHealthResult(dict):
    def __init__(__self__, *,
                 port: _builtins.int,
                 protocol: _builtins.str,
                 path: Optional[_builtins.str] = None,
                 status_code_from: Optional[_builtins.int] = None,
                 status_code_to: Optional[_builtins.int] = None,
                 timeout: Optional[_builtins.int] = None):
        """
        :param _builtins.int port: Health check port on the VM
        :param _builtins.str protocol: Protocol can be http or https
        :param _builtins.str path: API path to use for health check
        :param _builtins.int status_code_from: Lower limit for acceptable status code
        :param _builtins.int status_code_to: Upper limit for acceptable status code
        :param _builtins.int timeout: Health check timeout
        """
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if status_code_from is not None:
            pulumi.set(__self__, "status_code_from", status_code_from)
        if status_code_to is not None:
            pulumi.set(__self__, "status_code_to", status_code_to)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Health check port on the VM
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> _builtins.str:
        """
        Protocol can be http or https
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[_builtins.str]:
        """
        API path to use for health check
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="statusCodeFrom")
    def status_code_from(self) -> Optional[_builtins.int]:
        """
        Lower limit for acceptable status code
        """
        return pulumi.get(self, "status_code_from")

    @_builtins.property
    @pulumi.getter(name="statusCodeTo")
    def status_code_to(self) -> Optional[_builtins.int]:
        """
        Upper limit for acceptable status code
        """
        return pulumi.get(self, "status_code_to")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[_builtins.int]:
        """
        Health check timeout
        """
        return pulumi.get(self, "timeout")


@pulumi.output_type
class GetRuleScaleGroupHttpRoutingResult(dict):
    def __init__(__self__, *,
                 source_protocol: _builtins.str,
                 target_protocol: _builtins.str,
                 action: Optional[_builtins.str] = None,
                 source_port: Optional[_builtins.int] = None,
                 target_port: Optional[_builtins.int] = None):
        """
        :param _builtins.str source_protocol: Source protocol of the proxy can be http or https
        :param _builtins.str target_protocol: Target protocol of the instance can be http or https
        :param _builtins.str action: Organization Identifier for the Entity
        :param _builtins.int source_port: Port on the proxy
        :param _builtins.int target_port: Port on the VM
        """
        pulumi.set(__self__, "source_protocol", source_protocol)
        pulumi.set(__self__, "target_protocol", target_protocol)
        if action is not None:
            pulumi.set(__self__, "action", action)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if target_port is not None:
            pulumi.set(__self__, "target_port", target_port)

    @_builtins.property
    @pulumi.getter(name="sourceProtocol")
    def source_protocol(self) -> _builtins.str:
        """
        Source protocol of the proxy can be http or https
        """
        return pulumi.get(self, "source_protocol")

    @_builtins.property
    @pulumi.getter(name="targetProtocol")
    def target_protocol(self) -> _builtins.str:
        """
        Target protocol of the instance can be http or https
        """
        return pulumi.get(self, "target_protocol")

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[_builtins.str]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[_builtins.int]:
        """
        Port on the proxy
        """
        return pulumi.get(self, "source_port")

    @_builtins.property
    @pulumi.getter(name="targetPort")
    def target_port(self) -> Optional[_builtins.int]:
        """
        Port on the VM
        """
        return pulumi.get(self, "target_port")


@pulumi.output_type
class GetRuleScaleGroupScaleGroupResult(dict):
    def __init__(__self__, *,
                 desired: _builtins.int,
                 id: _builtins.str,
                 max: _builtins.int,
                 min: _builtins.int,
                 name: _builtins.str,
                 on_demand: _builtins.int,
                 region: Optional[_builtins.str] = None,
                 zone: Optional[_builtins.str] = None):
        """
        :param _builtins.int desired: Desired capacity of the Scaling Group
        :param _builtins.str id: ID of the Scaling Group
        :param _builtins.int max: Maximum capacity of the Scaling Group
        :param _builtins.int min: Minimum capacity of the Scaling Group
        :param _builtins.str name: Name of the Scaling Group
        :param _builtins.int on_demand: On-demand capacity of the Scaling Group
        :param _builtins.str region: Region of the Scaling Group
        :param _builtins.str zone: Zone of the Scaling Group. Needed for GCP only
        """
        pulumi.set(__self__, "desired", desired)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "max", max)
        pulumi.set(__self__, "min", min)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "on_demand", on_demand)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def desired(self) -> _builtins.int:
        """
        Desired capacity of the Scaling Group
        """
        return pulumi.get(self, "desired")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the Scaling Group
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def max(self) -> _builtins.int:
        """
        Maximum capacity of the Scaling Group
        """
        return pulumi.get(self, "max")

    @_builtins.property
    @pulumi.getter
    def min(self) -> _builtins.int:
        """
        Minimum capacity of the Scaling Group
        """
        return pulumi.get(self, "min")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the Scaling Group
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="onDemand")
    def on_demand(self) -> _builtins.int:
        """
        On-demand capacity of the Scaling Group
        """
        return pulumi.get(self, "on_demand")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        """
        Region of the Scaling Group
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[_builtins.str]:
        """
        Zone of the Scaling Group. Needed for GCP only
        """
        return pulumi.get(self, "zone")


@pulumi.output_type
class GetRuleVmDependResult(dict):
    def __init__(__self__, *,
                 rule_id: _builtins.int,
                 delay_in_sec: Optional[_builtins.int] = None):
        """
        :param _builtins.int rule_id: Rule id of the dependent rule
        :param _builtins.int delay_in_sec: Number of seconds the rule should wait after warming up the dependent rule
        """
        pulumi.set(__self__, "rule_id", rule_id)
        if delay_in_sec is not None:
            pulumi.set(__self__, "delay_in_sec", delay_in_sec)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> _builtins.int:
        """
        Rule id of the dependent rule
        """
        return pulumi.get(self, "rule_id")

    @_builtins.property
    @pulumi.getter(name="delayInSec")
    def delay_in_sec(self) -> Optional[_builtins.int]:
        """
        Number of seconds the rule should wait after warming up the dependent rule
        """
        return pulumi.get(self, "delay_in_sec")


@pulumi.output_type
class GetRuleVmFilterResult(dict):
    def __init__(__self__, *,
                 vm_ids: Sequence[_builtins.str],
                 regions: Optional[Sequence[_builtins.str]] = None,
                 tags: Optional[Sequence['outputs.GetRuleVmFilterTagResult']] = None,
                 zones: Optional[Sequence[_builtins.str]] = None):
        """
        :param Sequence[_builtins.str] vm_ids: Ids of instances that needs to be managed using the AutoStopping rules
        :param Sequence[_builtins.str] regions: Regions of instances that needs to be managed using the AutoStopping rules
        :param Sequence['GetRuleVmFilterTagArgs'] tags: Tags of instances that needs to be managed using the AutoStopping rules
        :param Sequence[_builtins.str] zones: Zones of instances that needs to be managed using the AutoStopping rules
        """
        pulumi.set(__self__, "vm_ids", vm_ids)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zones is not None:
            pulumi.set(__self__, "zones", zones)

    @_builtins.property
    @pulumi.getter(name="vmIds")
    def vm_ids(self) -> Sequence[_builtins.str]:
        """
        Ids of instances that needs to be managed using the AutoStopping rules
        """
        return pulumi.get(self, "vm_ids")

    @_builtins.property
    @pulumi.getter
    def regions(self) -> Optional[Sequence[_builtins.str]]:
        """
        Regions of instances that needs to be managed using the AutoStopping rules
        """
        return pulumi.get(self, "regions")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence['outputs.GetRuleVmFilterTagResult']]:
        """
        Tags of instances that needs to be managed using the AutoStopping rules
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def zones(self) -> Optional[Sequence[_builtins.str]]:
        """
        Zones of instances that needs to be managed using the AutoStopping rules
        """
        return pulumi.get(self, "zones")


@pulumi.output_type
class GetRuleVmFilterTagResult(dict):
    def __init__(__self__, *,
                 key: _builtins.str,
                 value: _builtins.str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> _builtins.str:
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetRuleVmHttpResult(dict):
    def __init__(__self__, *,
                 proxy_id: _builtins.str,
                 healths: Optional[Sequence['outputs.GetRuleVmHttpHealthResult']] = None,
                 routings: Optional[Sequence['outputs.GetRuleVmHttpRoutingResult']] = None):
        """
        :param _builtins.str proxy_id: Id of the proxy
        :param Sequence['GetRuleVmHttpHealthArgs'] healths: Health Check Details
        :param Sequence['GetRuleVmHttpRoutingArgs'] routings: Routing configuration used to access the instances
        """
        pulumi.set(__self__, "proxy_id", proxy_id)
        if healths is not None:
            pulumi.set(__self__, "healths", healths)
        if routings is not None:
            pulumi.set(__self__, "routings", routings)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the proxy
        """
        return pulumi.get(self, "proxy_id")

    @_builtins.property
    @pulumi.getter
    def healths(self) -> Optional[Sequence['outputs.GetRuleVmHttpHealthResult']]:
        """
        Health Check Details
        """
        return pulumi.get(self, "healths")

    @_builtins.property
    @pulumi.getter
    def routings(self) -> Optional[Sequence['outputs.GetRuleVmHttpRoutingResult']]:
        """
        Routing configuration used to access the instances
        """
        return pulumi.get(self, "routings")


@pulumi.output_type
class GetRuleVmHttpHealthResult(dict):
    def __init__(__self__, *,
                 port: _builtins.int,
                 protocol: _builtins.str,
                 path: Optional[_builtins.str] = None,
                 status_code_from: Optional[_builtins.int] = None,
                 status_code_to: Optional[_builtins.int] = None,
                 timeout: Optional[_builtins.int] = None):
        """
        :param _builtins.int port: Health check port on the VM
        :param _builtins.str protocol: Protocol can be http or https
        :param _builtins.str path: API path to use for health check
        :param _builtins.int status_code_from: Lower limit for acceptable status code
        :param _builtins.int status_code_to: Upper limit for acceptable status code
        :param _builtins.int timeout: Health check timeout
        """
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if status_code_from is not None:
            pulumi.set(__self__, "status_code_from", status_code_from)
        if status_code_to is not None:
            pulumi.set(__self__, "status_code_to", status_code_to)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Health check port on the VM
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> _builtins.str:
        """
        Protocol can be http or https
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[_builtins.str]:
        """
        API path to use for health check
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="statusCodeFrom")
    def status_code_from(self) -> Optional[_builtins.int]:
        """
        Lower limit for acceptable status code
        """
        return pulumi.get(self, "status_code_from")

    @_builtins.property
    @pulumi.getter(name="statusCodeTo")
    def status_code_to(self) -> Optional[_builtins.int]:
        """
        Upper limit for acceptable status code
        """
        return pulumi.get(self, "status_code_to")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[_builtins.int]:
        """
        Health check timeout
        """
        return pulumi.get(self, "timeout")


@pulumi.output_type
class GetRuleVmHttpRoutingResult(dict):
    def __init__(__self__, *,
                 source_protocol: _builtins.str,
                 target_protocol: _builtins.str,
                 action: Optional[_builtins.str] = None,
                 source_port: Optional[_builtins.int] = None,
                 target_port: Optional[_builtins.int] = None):
        """
        :param _builtins.str source_protocol: Source protocol of the proxy can be http or https
        :param _builtins.str target_protocol: Target protocol of the instance can be http or https
        :param _builtins.str action: Organization Identifier for the Entity
        :param _builtins.int source_port: Port on the proxy
        :param _builtins.int target_port: Port on the VM
        """
        pulumi.set(__self__, "source_protocol", source_protocol)
        pulumi.set(__self__, "target_protocol", target_protocol)
        if action is not None:
            pulumi.set(__self__, "action", action)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if target_port is not None:
            pulumi.set(__self__, "target_port", target_port)

    @_builtins.property
    @pulumi.getter(name="sourceProtocol")
    def source_protocol(self) -> _builtins.str:
        """
        Source protocol of the proxy can be http or https
        """
        return pulumi.get(self, "source_protocol")

    @_builtins.property
    @pulumi.getter(name="targetProtocol")
    def target_protocol(self) -> _builtins.str:
        """
        Target protocol of the instance can be http or https
        """
        return pulumi.get(self, "target_protocol")

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[_builtins.str]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[_builtins.int]:
        """
        Port on the proxy
        """
        return pulumi.get(self, "source_port")

    @_builtins.property
    @pulumi.getter(name="targetPort")
    def target_port(self) -> Optional[_builtins.int]:
        """
        Port on the VM
        """
        return pulumi.get(self, "target_port")


@pulumi.output_type
class GetRuleVmTcpResult(dict):
    def __init__(__self__, *,
                 proxy_id: _builtins.str,
                 forward_rules: Optional[Sequence['outputs.GetRuleVmTcpForwardRuleResult']] = None,
                 rdps: Optional[Sequence['outputs.GetRuleVmTcpRdpResult']] = None,
                 sshes: Optional[Sequence['outputs.GetRuleVmTcpSshResult']] = None):
        """
        :param _builtins.str proxy_id: Id of the Proxy
        :param Sequence['GetRuleVmTcpForwardRuleArgs'] forward_rules: Additional tcp forwarding rules
        :param Sequence['GetRuleVmTcpRdpArgs'] rdps: RDP configuration
        :param Sequence['GetRuleVmTcpSshArgs'] sshes: SSH configuration
        """
        pulumi.set(__self__, "proxy_id", proxy_id)
        if forward_rules is not None:
            pulumi.set(__self__, "forward_rules", forward_rules)
        if rdps is not None:
            pulumi.set(__self__, "rdps", rdps)
        if sshes is not None:
            pulumi.set(__self__, "sshes", sshes)

    @_builtins.property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> _builtins.str:
        """
        Id of the Proxy
        """
        return pulumi.get(self, "proxy_id")

    @_builtins.property
    @pulumi.getter(name="forwardRules")
    def forward_rules(self) -> Optional[Sequence['outputs.GetRuleVmTcpForwardRuleResult']]:
        """
        Additional tcp forwarding rules
        """
        return pulumi.get(self, "forward_rules")

    @_builtins.property
    @pulumi.getter
    def rdps(self) -> Optional[Sequence['outputs.GetRuleVmTcpRdpResult']]:
        """
        RDP configuration
        """
        return pulumi.get(self, "rdps")

    @_builtins.property
    @pulumi.getter
    def sshes(self) -> Optional[Sequence['outputs.GetRuleVmTcpSshResult']]:
        """
        SSH configuration
        """
        return pulumi.get(self, "sshes")


@pulumi.output_type
class GetRuleVmTcpForwardRuleResult(dict):
    def __init__(__self__, *,
                 port: _builtins.int,
                 connect_on: Optional[_builtins.int] = None):
        """
        :param _builtins.int port: Port to listen on the vm
        :param _builtins.int connect_on: Port to listen on the proxy
        """
        pulumi.set(__self__, "port", port)
        if connect_on is not None:
            pulumi.set(__self__, "connect_on", connect_on)

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Port to listen on the vm
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="connectOn")
    def connect_on(self) -> Optional[_builtins.int]:
        """
        Port to listen on the proxy
        """
        return pulumi.get(self, "connect_on")


@pulumi.output_type
class GetRuleVmTcpRdpResult(dict):
    def __init__(__self__, *,
                 connect_on: Optional[_builtins.int] = None,
                 port: Optional[_builtins.int] = None):
        """
        :param _builtins.int connect_on: Port to listen on the proxy
        :param _builtins.int port: Port to listen on the vm
        """
        if connect_on is not None:
            pulumi.set(__self__, "connect_on", connect_on)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="connectOn")
    def connect_on(self) -> Optional[_builtins.int]:
        """
        Port to listen on the proxy
        """
        return pulumi.get(self, "connect_on")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        Port to listen on the vm
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class GetRuleVmTcpSshResult(dict):
    def __init__(__self__, *,
                 connect_on: Optional[_builtins.int] = None,
                 port: Optional[_builtins.int] = None):
        """
        :param _builtins.int connect_on: Port to listen on the proxy
        :param _builtins.int port: Port to listen on the vm
        """
        if connect_on is not None:
            pulumi.set(__self__, "connect_on", connect_on)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="connectOn")
    def connect_on(self) -> Optional[_builtins.int]:
        """
        Port to listen on the proxy
        """
        return pulumi.get(self, "connect_on")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        Port to listen on the vm
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class GetScheduleRepeatResult(dict):
    def __init__(__self__, *,
                 days: Sequence[_builtins.str],
                 end_time: _builtins.str,
                 start_time: _builtins.str):
        """
        :param Sequence[_builtins.str] days: List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        :param _builtins.str end_time: Ending time of schedule action on the day. Accepted format is HH:MM. Eg : 20:00 for 8pm
        :param _builtins.str start_time: Starting time of schedule action on the day. Accepted format is HH:MM. Eg : 13:15 for 01:15pm
        """
        pulumi.set(__self__, "days", days)
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "start_time", start_time)

    @_builtins.property
    @pulumi.getter
    def days(self) -> Sequence[_builtins.str]:
        """
        List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        """
        return pulumi.get(self, "days")

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> _builtins.str:
        """
        Ending time of schedule action on the day. Accepted format is HH:MM. Eg : 20:00 for 8pm
        """
        return pulumi.get(self, "end_time")

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> _builtins.str:
        """
        Starting time of schedule action on the day. Accepted format is HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "start_time")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UserGroupArgs', 'UserGroup']

@pulumi.input_type
class UserGroupArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ldap_settings: Optional[pulumi.Input['UserGroupLdapSettingsArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input['UserGroupNotificationSettingsArgs']] = None,
                 permissions: Optional[pulumi.Input['UserGroupPermissionsArgs']] = None,
                 saml_settings: Optional[pulumi.Input['UserGroupSamlSettingsArgs']] = None):
        """
        The set of arguments for constructing a UserGroup resource.
        :param pulumi.Input[_builtins.str] description: The description of the user group.
        :param pulumi.Input['UserGroupLdapSettingsArgs'] ldap_settings: The LDAP settings for the user group.
        :param pulumi.Input[_builtins.str] name: The name of the user group.
        :param pulumi.Input['UserGroupNotificationSettingsArgs'] notification_settings: The notification settings of the user group.
        :param pulumi.Input['UserGroupPermissionsArgs'] permissions: The permissions of the user group.
        :param pulumi.Input['UserGroupSamlSettingsArgs'] saml_settings: The SAML settings for the user group.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ldap_settings is not None:
            pulumi.set(__self__, "ldap_settings", ldap_settings)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_settings is not None:
            pulumi.set(__self__, "notification_settings", notification_settings)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if saml_settings is not None:
            pulumi.set(__self__, "saml_settings", saml_settings)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the user group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="ldapSettings")
    def ldap_settings(self) -> Optional[pulumi.Input['UserGroupLdapSettingsArgs']]:
        """
        The LDAP settings for the user group.
        """
        return pulumi.get(self, "ldap_settings")

    @ldap_settings.setter
    def ldap_settings(self, value: Optional[pulumi.Input['UserGroupLdapSettingsArgs']]):
        pulumi.set(self, "ldap_settings", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> Optional[pulumi.Input['UserGroupNotificationSettingsArgs']]:
        """
        The notification settings of the user group.
        """
        return pulumi.get(self, "notification_settings")

    @notification_settings.setter
    def notification_settings(self, value: Optional[pulumi.Input['UserGroupNotificationSettingsArgs']]):
        pulumi.set(self, "notification_settings", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input['UserGroupPermissionsArgs']]:
        """
        The permissions of the user group.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input['UserGroupPermissionsArgs']]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter(name="samlSettings")
    def saml_settings(self) -> Optional[pulumi.Input['UserGroupSamlSettingsArgs']]:
        """
        The SAML settings for the user group.
        """
        return pulumi.get(self, "saml_settings")

    @saml_settings.setter
    def saml_settings(self, value: Optional[pulumi.Input['UserGroupSamlSettingsArgs']]):
        pulumi.set(self, "saml_settings", value)


@pulumi.input_type
class _UserGroupState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 imported_by_scim: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 ldap_settings: Optional[pulumi.Input['UserGroupLdapSettingsArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input['UserGroupNotificationSettingsArgs']] = None,
                 permissions: Optional[pulumi.Input['UserGroupPermissionsArgs']] = None,
                 saml_settings: Optional[pulumi.Input['UserGroupSamlSettingsArgs']] = None):
        """
        Input properties used for looking up and filtering UserGroup resources.
        :param pulumi.Input[_builtins.str] description: The description of the user group.
        :param pulumi.Input[_builtins.bool] imported_by_scim: Indicates whether the user group was imported by SCIM.
        :param pulumi.Input[_builtins.bool] is_sso_linked: Indicates whether the user group is linked to an SSO provider.
        :param pulumi.Input['UserGroupLdapSettingsArgs'] ldap_settings: The LDAP settings for the user group.
        :param pulumi.Input[_builtins.str] name: The name of the user group.
        :param pulumi.Input['UserGroupNotificationSettingsArgs'] notification_settings: The notification settings of the user group.
        :param pulumi.Input['UserGroupPermissionsArgs'] permissions: The permissions of the user group.
        :param pulumi.Input['UserGroupSamlSettingsArgs'] saml_settings: The SAML settings for the user group.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if imported_by_scim is not None:
            pulumi.set(__self__, "imported_by_scim", imported_by_scim)
        if is_sso_linked is not None:
            pulumi.set(__self__, "is_sso_linked", is_sso_linked)
        if ldap_settings is not None:
            pulumi.set(__self__, "ldap_settings", ldap_settings)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_settings is not None:
            pulumi.set(__self__, "notification_settings", notification_settings)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if saml_settings is not None:
            pulumi.set(__self__, "saml_settings", saml_settings)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the user group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="importedByScim")
    def imported_by_scim(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the user group was imported by SCIM.
        """
        return pulumi.get(self, "imported_by_scim")

    @imported_by_scim.setter
    def imported_by_scim(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "imported_by_scim", value)

    @_builtins.property
    @pulumi.getter(name="isSsoLinked")
    def is_sso_linked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the user group is linked to an SSO provider.
        """
        return pulumi.get(self, "is_sso_linked")

    @is_sso_linked.setter
    def is_sso_linked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_sso_linked", value)

    @_builtins.property
    @pulumi.getter(name="ldapSettings")
    def ldap_settings(self) -> Optional[pulumi.Input['UserGroupLdapSettingsArgs']]:
        """
        The LDAP settings for the user group.
        """
        return pulumi.get(self, "ldap_settings")

    @ldap_settings.setter
    def ldap_settings(self, value: Optional[pulumi.Input['UserGroupLdapSettingsArgs']]):
        pulumi.set(self, "ldap_settings", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> Optional[pulumi.Input['UserGroupNotificationSettingsArgs']]:
        """
        The notification settings of the user group.
        """
        return pulumi.get(self, "notification_settings")

    @notification_settings.setter
    def notification_settings(self, value: Optional[pulumi.Input['UserGroupNotificationSettingsArgs']]):
        pulumi.set(self, "notification_settings", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input['UserGroupPermissionsArgs']]:
        """
        The permissions of the user group.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input['UserGroupPermissionsArgs']]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter(name="samlSettings")
    def saml_settings(self) -> Optional[pulumi.Input['UserGroupSamlSettingsArgs']]:
        """
        The SAML settings for the user group.
        """
        return pulumi.get(self, "saml_settings")

    @saml_settings.setter
    def saml_settings(self, value: Optional[pulumi.Input['UserGroupSamlSettingsArgs']]):
        pulumi.set(self, "saml_settings", value)


@pulumi.type_token("harness:index/userGroup:UserGroup")
class UserGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ldap_settings: Optional[pulumi.Input[Union['UserGroupLdapSettingsArgs', 'UserGroupLdapSettingsArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input[Union['UserGroupNotificationSettingsArgs', 'UserGroupNotificationSettingsArgsDict']]] = None,
                 permissions: Optional[pulumi.Input[Union['UserGroupPermissionsArgs', 'UserGroupPermissionsArgsDict']]] = None,
                 saml_settings: Optional[pulumi.Input[Union['UserGroupSamlSettingsArgs', 'UserGroupSamlSettingsArgsDict']]] = None,
                 __props__=None):
        """
        Resource for creating a Harness user group

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.UserGroup("example",
            name="example-group",
            description="This group demonstrates account level and resource level permissions.",
            permissions={
                "account_permissions": [
                    "ADMINISTER_OTHER_ACCOUNT_FUNCTIONS",
                    "MANAGE_API_KEYS",
                ],
                "app_permissions": {
                    "alls": [{
                        "actions": [
                            "CREATE",
                            "READ",
                            "UPDATE",
                            "DELETE",
                        ],
                    }],
                    "deployments": [
                        {
                            "actions": [
                                "READ",
                                "ROLLBACK_WORKFLOW",
                                "EXECUTE_PIPELINE",
                                "EXECUTE_WORKFLOW",
                            ],
                            "filters": ["NON_PRODUCTION_ENVIRONMENTS"],
                        },
                        {
                            "actions": ["READ"],
                            "filters": ["PRODUCTION_ENVIRONMENTS"],
                        },
                    ],
                    "environments": [
                        {
                            "actions": [
                                "CREATE",
                                "READ",
                                "UPDATE",
                                "DELETE",
                            ],
                            "filters": ["NON_PRODUCTION_ENVIRONMENTS"],
                        },
                        {
                            "actions": ["READ"],
                            "filters": ["PRODUCTION_ENVIRONMENTS"],
                        },
                    ],
                    "pipelines": [
                        {
                            "actions": [
                                "CREATE",
                                "READ",
                                "UPDATE",
                                "DELETE",
                            ],
                            "filters": ["NON_PRODUCTION_PIPELINES"],
                        },
                        {
                            "actions": ["READ"],
                            "filters": ["PRODUCTION_PIPELINES"],
                        },
                    ],
                    "provisioners": [
                        {
                            "actions": [
                                "UPDATE",
                                "DELETE",
                            ],
                        },
                        {
                            "actions": [
                                "CREATE",
                                "READ",
                            ],
                        },
                    ],
                    "services": [
                        {
                            "actions": [
                                "UPDATE",
                                "DELETE",
                            ],
                        },
                        {
                            "actions": [
                                "UPDATE",
                                "DELETE",
                            ],
                        },
                    ],
                    "templates": [{
                        "actions": [
                            "CREATE",
                            "READ",
                            "UPDATE",
                            "DELETE",
                        ],
                    }],
                    "workflows": [
                        {
                            "actions": [
                                "UPDATE",
                                "DELETE",
                            ],
                            "filters": ["NON_PRODUCTION_WORKFLOWS"],
                        },
                        {
                            "actions": [
                                "CREATE",
                                "READ",
                            ],
                            "filters": [
                                "PRODUCTION_WORKFLOWS",
                                "WORKFLOW_TEMPLATES",
                            ],
                        },
                    ],
                },
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the id of the user group

        ```sh
        $ pulumi import harness:index/userGroup:UserGroup example <USER_GROUP_ID>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the user group.
        :param pulumi.Input[Union['UserGroupLdapSettingsArgs', 'UserGroupLdapSettingsArgsDict']] ldap_settings: The LDAP settings for the user group.
        :param pulumi.Input[_builtins.str] name: The name of the user group.
        :param pulumi.Input[Union['UserGroupNotificationSettingsArgs', 'UserGroupNotificationSettingsArgsDict']] notification_settings: The notification settings of the user group.
        :param pulumi.Input[Union['UserGroupPermissionsArgs', 'UserGroupPermissionsArgsDict']] permissions: The permissions of the user group.
        :param pulumi.Input[Union['UserGroupSamlSettingsArgs', 'UserGroupSamlSettingsArgsDict']] saml_settings: The SAML settings for the user group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[UserGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness user group

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.UserGroup("example",
            name="example-group",
            description="This group demonstrates account level and resource level permissions.",
            permissions={
                "account_permissions": [
                    "ADMINISTER_OTHER_ACCOUNT_FUNCTIONS",
                    "MANAGE_API_KEYS",
                ],
                "app_permissions": {
                    "alls": [{
                        "actions": [
                            "CREATE",
                            "READ",
                            "UPDATE",
                            "DELETE",
                        ],
                    }],
                    "deployments": [
                        {
                            "actions": [
                                "READ",
                                "ROLLBACK_WORKFLOW",
                                "EXECUTE_PIPELINE",
                                "EXECUTE_WORKFLOW",
                            ],
                            "filters": ["NON_PRODUCTION_ENVIRONMENTS"],
                        },
                        {
                            "actions": ["READ"],
                            "filters": ["PRODUCTION_ENVIRONMENTS"],
                        },
                    ],
                    "environments": [
                        {
                            "actions": [
                                "CREATE",
                                "READ",
                                "UPDATE",
                                "DELETE",
                            ],
                            "filters": ["NON_PRODUCTION_ENVIRONMENTS"],
                        },
                        {
                            "actions": ["READ"],
                            "filters": ["PRODUCTION_ENVIRONMENTS"],
                        },
                    ],
                    "pipelines": [
                        {
                            "actions": [
                                "CREATE",
                                "READ",
                                "UPDATE",
                                "DELETE",
                            ],
                            "filters": ["NON_PRODUCTION_PIPELINES"],
                        },
                        {
                            "actions": ["READ"],
                            "filters": ["PRODUCTION_PIPELINES"],
                        },
                    ],
                    "provisioners": [
                        {
                            "actions": [
                                "UPDATE",
                                "DELETE",
                            ],
                        },
                        {
                            "actions": [
                                "CREATE",
                                "READ",
                            ],
                        },
                    ],
                    "services": [
                        {
                            "actions": [
                                "UPDATE",
                                "DELETE",
                            ],
                        },
                        {
                            "actions": [
                                "UPDATE",
                                "DELETE",
                            ],
                        },
                    ],
                    "templates": [{
                        "actions": [
                            "CREATE",
                            "READ",
                            "UPDATE",
                            "DELETE",
                        ],
                    }],
                    "workflows": [
                        {
                            "actions": [
                                "UPDATE",
                                "DELETE",
                            ],
                            "filters": ["NON_PRODUCTION_WORKFLOWS"],
                        },
                        {
                            "actions": [
                                "CREATE",
                                "READ",
                            ],
                            "filters": [
                                "PRODUCTION_WORKFLOWS",
                                "WORKFLOW_TEMPLATES",
                            ],
                        },
                    ],
                },
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the id of the user group

        ```sh
        $ pulumi import harness:index/userGroup:UserGroup example <USER_GROUP_ID>
        ```

        :param str resource_name: The name of the resource.
        :param UserGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ldap_settings: Optional[pulumi.Input[Union['UserGroupLdapSettingsArgs', 'UserGroupLdapSettingsArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input[Union['UserGroupNotificationSettingsArgs', 'UserGroupNotificationSettingsArgsDict']]] = None,
                 permissions: Optional[pulumi.Input[Union['UserGroupPermissionsArgs', 'UserGroupPermissionsArgsDict']]] = None,
                 saml_settings: Optional[pulumi.Input[Union['UserGroupSamlSettingsArgs', 'UserGroupSamlSettingsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserGroupArgs.__new__(UserGroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["ldap_settings"] = ldap_settings
            __props__.__dict__["name"] = name
            __props__.__dict__["notification_settings"] = notification_settings
            __props__.__dict__["permissions"] = permissions
            __props__.__dict__["saml_settings"] = saml_settings
            __props__.__dict__["imported_by_scim"] = None
            __props__.__dict__["is_sso_linked"] = None
        super(UserGroup, __self__).__init__(
            'harness:index/userGroup:UserGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            imported_by_scim: Optional[pulumi.Input[_builtins.bool]] = None,
            is_sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
            ldap_settings: Optional[pulumi.Input[Union['UserGroupLdapSettingsArgs', 'UserGroupLdapSettingsArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notification_settings: Optional[pulumi.Input[Union['UserGroupNotificationSettingsArgs', 'UserGroupNotificationSettingsArgsDict']]] = None,
            permissions: Optional[pulumi.Input[Union['UserGroupPermissionsArgs', 'UserGroupPermissionsArgsDict']]] = None,
            saml_settings: Optional[pulumi.Input[Union['UserGroupSamlSettingsArgs', 'UserGroupSamlSettingsArgsDict']]] = None) -> 'UserGroup':
        """
        Get an existing UserGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the user group.
        :param pulumi.Input[_builtins.bool] imported_by_scim: Indicates whether the user group was imported by SCIM.
        :param pulumi.Input[_builtins.bool] is_sso_linked: Indicates whether the user group is linked to an SSO provider.
        :param pulumi.Input[Union['UserGroupLdapSettingsArgs', 'UserGroupLdapSettingsArgsDict']] ldap_settings: The LDAP settings for the user group.
        :param pulumi.Input[_builtins.str] name: The name of the user group.
        :param pulumi.Input[Union['UserGroupNotificationSettingsArgs', 'UserGroupNotificationSettingsArgsDict']] notification_settings: The notification settings of the user group.
        :param pulumi.Input[Union['UserGroupPermissionsArgs', 'UserGroupPermissionsArgsDict']] permissions: The permissions of the user group.
        :param pulumi.Input[Union['UserGroupSamlSettingsArgs', 'UserGroupSamlSettingsArgsDict']] saml_settings: The SAML settings for the user group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserGroupState.__new__(_UserGroupState)

        __props__.__dict__["description"] = description
        __props__.__dict__["imported_by_scim"] = imported_by_scim
        __props__.__dict__["is_sso_linked"] = is_sso_linked
        __props__.__dict__["ldap_settings"] = ldap_settings
        __props__.__dict__["name"] = name
        __props__.__dict__["notification_settings"] = notification_settings
        __props__.__dict__["permissions"] = permissions
        __props__.__dict__["saml_settings"] = saml_settings
        return UserGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the user group.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="importedByScim")
    def imported_by_scim(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the user group was imported by SCIM.
        """
        return pulumi.get(self, "imported_by_scim")

    @_builtins.property
    @pulumi.getter(name="isSsoLinked")
    def is_sso_linked(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the user group is linked to an SSO provider.
        """
        return pulumi.get(self, "is_sso_linked")

    @_builtins.property
    @pulumi.getter(name="ldapSettings")
    def ldap_settings(self) -> pulumi.Output[Optional['outputs.UserGroupLdapSettings']]:
        """
        The LDAP settings for the user group.
        """
        return pulumi.get(self, "ldap_settings")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the user group.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> pulumi.Output[Optional['outputs.UserGroupNotificationSettings']]:
        """
        The notification settings of the user group.
        """
        return pulumi.get(self, "notification_settings")

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Optional['outputs.UserGroupPermissions']]:
        """
        The permissions of the user group.
        """
        return pulumi.get(self, "permissions")

    @_builtins.property
    @pulumi.getter(name="samlSettings")
    def saml_settings(self) -> pulumi.Output[Optional['outputs.UserGroupSamlSettings']]:
        """
        The SAML settings for the user group.
        """
        return pulumi.get(self, "saml_settings")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['YamlConfigArgs', 'YamlConfig']

@pulumi.input_type
class YamlConfigArgs:
    def __init__(__self__, *,
                 content: pulumi.Input[_builtins.str],
                 path: pulumi.Input[_builtins.str],
                 app_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a YamlConfig resource.
        :param pulumi.Input[_builtins.str] content: The raw YAML configuration.
        :param pulumi.Input[_builtins.str] path: The path of the resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application. This is required for all resources except global ones.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "path", path)
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)

    @_builtins.property
    @pulumi.getter
    def content(self) -> pulumi.Input[_builtins.str]:
        """
        The raw YAML configuration.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "content", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Input[_builtins.str]:
        """
        The path of the resource.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the application. This is required for all resources except global ones.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)


@pulumi.input_type
class _YamlConfigState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering YamlConfig resources.
        :param pulumi.Input[_builtins.str] app_id: The id of the application. This is required for all resources except global ones.
        :param pulumi.Input[_builtins.str] content: The raw YAML configuration.
        :param pulumi.Input[_builtins.str] name: The name of the resource.
        :param pulumi.Input[_builtins.str] path: The path of the resource.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if content is not None:
            pulumi.set(__self__, "content", content)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path is not None:
            pulumi.set(__self__, "path", path)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the application. This is required for all resources except global ones.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The raw YAML configuration.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "content", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path of the resource.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)


@pulumi.type_token("harness:index/yamlConfig:YamlConfig")
class YamlConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a raw YAML configuration in Harness. Note: This works for all objects EXCEPT application objects. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.YamlConfig("test",
            path="Setup/Cloud Providers/Kubernetes.yaml",
            content=\"\"\"harnessApiVersion: '1.0'
        type: KUBERNETES_CLUSTER
        delegateSelectors:
        - k8s
        skipValidation: true
        useKubernetesDelegate: true
        \"\"\")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Importing a global config only using the yaml path

        ```sh
        $ pulumi import harness:index/yamlConfig:YamlConfig k8s_cloudprovider "Setup/Cloud Providers/kubernetes.yaml"
        ```

        Importing a service which requires both the application id and the yaml path.

        ```sh
        $ pulumi import harness:index/yamlConfig:YamlConfig k8s_cloudprovider "Setup/Applications/MyApp/Services/MyService/Index.yaml:<APPLICATION_ID>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application. This is required for all resources except global ones.
        :param pulumi.Input[_builtins.str] content: The raw YAML configuration.
        :param pulumi.Input[_builtins.str] path: The path of the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: YamlConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a raw YAML configuration in Harness. Note: This works for all objects EXCEPT application objects. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.YamlConfig("test",
            path="Setup/Cloud Providers/Kubernetes.yaml",
            content=\"\"\"harnessApiVersion: '1.0'
        type: KUBERNETES_CLUSTER
        delegateSelectors:
        - k8s
        skipValidation: true
        useKubernetesDelegate: true
        \"\"\")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Importing a global config only using the yaml path

        ```sh
        $ pulumi import harness:index/yamlConfig:YamlConfig k8s_cloudprovider "Setup/Cloud Providers/kubernetes.yaml"
        ```

        Importing a service which requires both the application id and the yaml path.

        ```sh
        $ pulumi import harness:index/yamlConfig:YamlConfig k8s_cloudprovider "Setup/Applications/MyApp/Services/MyService/Index.yaml:<APPLICATION_ID>"
        ```

        :param str resource_name: The name of the resource.
        :param YamlConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(YamlConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = YamlConfigArgs.__new__(YamlConfigArgs)

            __props__.__dict__["app_id"] = app_id
            if content is None and not opts.urn:
                raise TypeError("Missing required property 'content'")
            __props__.__dict__["content"] = content
            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            __props__.__dict__["name"] = None
        super(YamlConfig, __self__).__init__(
            'harness:index/yamlConfig:YamlConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            content: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None) -> 'YamlConfig':
        """
        Get an existing YamlConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application. This is required for all resources except global ones.
        :param pulumi.Input[_builtins.str] content: The raw YAML configuration.
        :param pulumi.Input[_builtins.str] name: The name of the resource.
        :param pulumi.Input[_builtins.str] path: The path of the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _YamlConfigState.__new__(_YamlConfigState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["content"] = content
        __props__.__dict__["name"] = name
        __props__.__dict__["path"] = path
        return YamlConfig(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The id of the application. This is required for all resources except global ones.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def content(self) -> pulumi.Output[_builtins.str]:
        """
        The raw YAML configuration.
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        """
        The path of the resource.
        """
        return pulumi.get(self, "path")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIacmDefaultPipelineResult',
    'AwaitableGetIacmDefaultPipelineResult',
    'get_iacm_default_pipeline',
    'get_iacm_default_pipeline_output',
]

@pulumi.output_type
class GetIacmDefaultPipelineResult:
    """
    A collection of values returned by getIacmDefaultPipeline.
    """
    def __init__(__self__, id=None, operation=None, org_id=None, pipeline=None, project_id=None, provisioner_type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if operation and not isinstance(operation, str):
            raise TypeError("Expected argument 'operation' to be a str")
        pulumi.set(__self__, "operation", operation)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if pipeline and not isinstance(pipeline, str):
            raise TypeError("Expected argument 'pipeline' to be a str")
        pulumi.set(__self__, "pipeline", pipeline)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if provisioner_type and not isinstance(provisioner_type, str):
            raise TypeError("Expected argument 'provisioner_type' to be a str")
        pulumi.set(__self__, "provisioner_type", provisioner_type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def operation(self) -> _builtins.str:
        """
        The operation associated with this default.
        """
        return pulumi.get(self, "operation")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Organization identifier of the organization the default pipelines resides in.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def pipeline(self) -> _builtins.str:
        """
        The pipeline associated with this default.
        """
        return pulumi.get(self, "pipeline")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Project identifier of the project the default pipelines resides in.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> _builtins.str:
        """
        The provisioner associated with this default.
        """
        return pulumi.get(self, "provisioner_type")


class AwaitableGetIacmDefaultPipelineResult(GetIacmDefaultPipelineResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIacmDefaultPipelineResult(
            id=self.id,
            operation=self.operation,
            org_id=self.org_id,
            pipeline=self.pipeline,
            project_id=self.project_id,
            provisioner_type=self.provisioner_type)


def get_iacm_default_pipeline(operation: Optional[_builtins.str] = None,
                              org_id: Optional[_builtins.str] = None,
                              project_id: Optional[_builtins.str] = None,
                              provisioner_type: Optional[_builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIacmDefaultPipelineResult:
    """
    Data source for retrieving IACM default pipelines.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_iacm_default_pipeline(org_id=test["id"],
        project_id=test_harness_platform_project["id"],
        provisioner_type="terraform",
        operation="plan")
    ```


    :param _builtins.str operation: The operation associated with this default.
    :param _builtins.str org_id: Organization identifier of the organization the default pipelines resides in.
    :param _builtins.str project_id: Project identifier of the project the default pipelines resides in.
    :param _builtins.str provisioner_type: The provisioner associated with this default.
    """
    __args__ = dict()
    __args__['operation'] = operation
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['provisionerType'] = provisioner_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getIacmDefaultPipeline:getIacmDefaultPipeline', __args__, opts=opts, typ=GetIacmDefaultPipelineResult).value

    return AwaitableGetIacmDefaultPipelineResult(
        id=pulumi.get(__ret__, 'id'),
        operation=pulumi.get(__ret__, 'operation'),
        org_id=pulumi.get(__ret__, 'org_id'),
        pipeline=pulumi.get(__ret__, 'pipeline'),
        project_id=pulumi.get(__ret__, 'project_id'),
        provisioner_type=pulumi.get(__ret__, 'provisioner_type'))
def get_iacm_default_pipeline_output(operation: Optional[pulumi.Input[_builtins.str]] = None,
                                     org_id: Optional[pulumi.Input[_builtins.str]] = None,
                                     project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                     provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIacmDefaultPipelineResult]:
    """
    Data source for retrieving IACM default pipelines.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_iacm_default_pipeline(org_id=test["id"],
        project_id=test_harness_platform_project["id"],
        provisioner_type="terraform",
        operation="plan")
    ```


    :param _builtins.str operation: The operation associated with this default.
    :param _builtins.str org_id: Organization identifier of the organization the default pipelines resides in.
    :param _builtins.str project_id: Project identifier of the project the default pipelines resides in.
    :param _builtins.str provisioner_type: The provisioner associated with this default.
    """
    __args__ = dict()
    __args__['operation'] = operation
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['provisionerType'] = provisioner_type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getIacmDefaultPipeline:getIacmDefaultPipeline', __args__, opts=opts, typ=GetIacmDefaultPipelineResult)
    return __ret__.apply(lambda __response__: GetIacmDefaultPipelineResult(
        id=pulumi.get(__response__, 'id'),
        operation=pulumi.get(__response__, 'operation'),
        org_id=pulumi.get(__response__, 'org_id'),
        pipeline=pulumi.get(__response__, 'pipeline'),
        project_id=pulumi.get(__response__, 'project_id'),
        provisioner_type=pulumi.get(__response__, 'provisioner_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRuleEcsResult',
    'AwaitableGetRuleEcsResult',
    'get_rule_ecs',
    'get_rule_ecs_output',
]

@pulumi.output_type
class GetRuleEcsResult:
    """
    A collection of values returned by getRuleEcs.
    """
    def __init__(__self__, cloud_connector_id=None, container=None, custom_domains=None, depends=None, https=None, id=None, identifier=None, idle_time_mins=None, name=None):
        if cloud_connector_id and not isinstance(cloud_connector_id, str):
            raise TypeError("Expected argument 'cloud_connector_id' to be a str")
        pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        if container and not isinstance(container, dict):
            raise TypeError("Expected argument 'container' to be a dict")
        pulumi.set(__self__, "container", container)
        if custom_domains and not isinstance(custom_domains, list):
            raise TypeError("Expected argument 'custom_domains' to be a list")
        pulumi.set(__self__, "custom_domains", custom_domains)
        if depends and not isinstance(depends, list):
            raise TypeError("Expected argument 'depends' to be a list")
        pulumi.set(__self__, "depends", depends)
        if https and not isinstance(https, list):
            raise TypeError("Expected argument 'https' to be a list")
        pulumi.set(__self__, "https", https)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, float):
            raise TypeError("Expected argument 'identifier' to be a float")
        pulumi.set(__self__, "identifier", identifier)
        if idle_time_mins and not isinstance(idle_time_mins, int):
            raise TypeError("Expected argument 'idle_time_mins' to be a int")
        pulumi.set(__self__, "idle_time_mins", idle_time_mins)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> _builtins.str:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @_builtins.property
    @pulumi.getter
    def container(self) -> Optional['outputs.GetRuleEcsContainerResult']:
        return pulumi.get(self, "container")

    @_builtins.property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> Optional[Sequence[_builtins.str]]:
        """
        Custom URLs used to access the instances
        """
        return pulumi.get(self, "custom_domains")

    @_builtins.property
    @pulumi.getter
    def depends(self) -> Optional[Sequence['outputs.GetRuleEcsDependResult']]:
        """
        Dependent rules
        """
        return pulumi.get(self, "depends")

    @_builtins.property
    @pulumi.getter
    def https(self) -> Optional[Sequence['outputs.GetRuleEcsHttpResult']]:
        """
        Http routing configuration
        """
        return pulumi.get(self, "https")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.float:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="idleTimeMins")
    def idle_time_mins(self) -> Optional[_builtins.int]:
        """
        Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        """
        return pulumi.get(self, "idle_time_mins")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")


class AwaitableGetRuleEcsResult(GetRuleEcsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRuleEcsResult(
            cloud_connector_id=self.cloud_connector_id,
            container=self.container,
            custom_domains=self.custom_domains,
            depends=self.depends,
            https=self.https,
            id=self.id,
            identifier=self.identifier,
            idle_time_mins=self.idle_time_mins,
            name=self.name)


def get_rule_ecs(cloud_connector_id: Optional[_builtins.str] = None,
                 container: Optional[Union['GetRuleEcsContainerArgs', 'GetRuleEcsContainerArgsDict']] = None,
                 custom_domains: Optional[Sequence[_builtins.str]] = None,
                 depends: Optional[Sequence[Union['GetRuleEcsDependArgs', 'GetRuleEcsDependArgsDict']]] = None,
                 https: Optional[Sequence[Union['GetRuleEcsHttpArgs', 'GetRuleEcsHttpArgsDict']]] = None,
                 idle_time_mins: Optional[_builtins.int] = None,
                 name: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRuleEcsResult:
    """
    Data source for retrieving a Harness AutoStopping rule for ECS services.

    ## Example Usage


    :param _builtins.str cloud_connector_id: Id of the cloud connector
    :param Sequence[_builtins.str] custom_domains: Custom URLs used to access the instances
    :param Sequence[Union['GetRuleEcsDependArgs', 'GetRuleEcsDependArgsDict']] depends: Dependent rules
    :param Sequence[Union['GetRuleEcsHttpArgs', 'GetRuleEcsHttpArgsDict']] https: Http routing configuration
    :param _builtins.int idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
    :param _builtins.str name: Name of the rule
    """
    __args__ = dict()
    __args__['cloudConnectorId'] = cloud_connector_id
    __args__['container'] = container
    __args__['customDomains'] = custom_domains
    __args__['depends'] = depends
    __args__['https'] = https
    __args__['idleTimeMins'] = idle_time_mins
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:autostopping/getRuleEcs:getRuleEcs', __args__, opts=opts, typ=GetRuleEcsResult).value

    return AwaitableGetRuleEcsResult(
        cloud_connector_id=pulumi.get(__ret__, 'cloud_connector_id'),
        container=pulumi.get(__ret__, 'container'),
        custom_domains=pulumi.get(__ret__, 'custom_domains'),
        depends=pulumi.get(__ret__, 'depends'),
        https=pulumi.get(__ret__, 'https'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        idle_time_mins=pulumi.get(__ret__, 'idle_time_mins'),
        name=pulumi.get(__ret__, 'name'))
def get_rule_ecs_output(cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                        container: Optional[pulumi.Input[Optional[Union['GetRuleEcsContainerArgs', 'GetRuleEcsContainerArgsDict']]]] = None,
                        custom_domains: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                        depends: Optional[pulumi.Input[Optional[Sequence[Union['GetRuleEcsDependArgs', 'GetRuleEcsDependArgsDict']]]]] = None,
                        https: Optional[pulumi.Input[Optional[Sequence[Union['GetRuleEcsHttpArgs', 'GetRuleEcsHttpArgsDict']]]]] = None,
                        idle_time_mins: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                        name: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRuleEcsResult]:
    """
    Data source for retrieving a Harness AutoStopping rule for ECS services.

    ## Example Usage


    :param _builtins.str cloud_connector_id: Id of the cloud connector
    :param Sequence[_builtins.str] custom_domains: Custom URLs used to access the instances
    :param Sequence[Union['GetRuleEcsDependArgs', 'GetRuleEcsDependArgsDict']] depends: Dependent rules
    :param Sequence[Union['GetRuleEcsHttpArgs', 'GetRuleEcsHttpArgsDict']] https: Http routing configuration
    :param _builtins.int idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
    :param _builtins.str name: Name of the rule
    """
    __args__ = dict()
    __args__['cloudConnectorId'] = cloud_connector_id
    __args__['container'] = container
    __args__['customDomains'] = custom_domains
    __args__['depends'] = depends
    __args__['https'] = https
    __args__['idleTimeMins'] = idle_time_mins
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:autostopping/getRuleEcs:getRuleEcs', __args__, opts=opts, typ=GetRuleEcsResult)
    return __ret__.apply(lambda __response__: GetRuleEcsResult(
        cloud_connector_id=pulumi.get(__response__, 'cloud_connector_id'),
        container=pulumi.get(__response__, 'container'),
        custom_domains=pulumi.get(__response__, 'custom_domains'),
        depends=pulumi.get(__response__, 'depends'),
        https=pulumi.get(__response__, 'https'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        idle_time_mins=pulumi.get(__response__, 'idle_time_mins'),
        name=pulumi.get(__response__, 'name')))
